import { create } from 'zustand'
import axios from 'axios'

export interface Message {
  id?: string
  role: 'user' | 'assistant'
  content: string
}

interface State {
  ai: string
  setAI: (ai: string) => void
  messages: Message[]
  isLoading: boolean
  post: (data: { content: string }) => Promise<void>
}

// Zustand 状态管理
export const useAIStore = create<State>((set, get) => ({
  ai: localStorage.getItem('ai') || 'yiyan',
  setAI: (ai) => {
    localStorage.setItem('ai', ai)
    set({ ai })
  },
  messages: [],
  isLoading: false,

  post: async (data) => {
    const { ai, messages } = get()
    set({ isLoading: true, messages: [...messages, { role: 'user', content: data.content }] })

    try {
      let response = ''
      switch (ai) {
        case 'yiyan':
          response = await yiyan(data)
          break
        case 'deepseek':
          response = await deepseek(data)
          break
        case 'qwen':
          response = await qwen(data)
          break
        case 'tiangong':
          response = await tiangong(data)
          break
        default:
          throw new Error('未找到对应的 AI 配置')
      }
      set((state) => ({
        messages: [...state.messages, { role: 'assistant', content: response }],
        isLoading: false,
      }))
    } catch (err) {
      console.error('AI 请求失败:', err)
      set({ isLoading: false })
    }
  },
}))

// AI API 调用函数
async function yiyan(data: any) {
  const resp = await axios.post('/api/qianfan/chat', { messages: [{ role: 'user', content: data.content }] })
  return resp.data.result
}

async function deepseek(data: any) {
  const resp = await axios.post('/api/deepseek/chat/completions', {
    model: 'deepseek-chat',
    messages: [{ role: 'user', content: data.content }],
  })
  return resp.data.choices[0]?.message?.content || ''
}

async function qwen(data: any) {
  const resp = await axios.post('/api/qwen/chat/completions', {
    model: 'qwen-max',
    messages: [{ role: 'user', content: data.content }],
  })
  return resp.data.choices[0]?.message?.content || ''
}

async function tiangong(data: any) {
  const resp = await axios.post('/api/tiangong/chat', {
    chat_history: [{ role: 'user', content: data.content }],
  })
  return resp.data.result
}
